# Contributing to geoPFA

This document discusses how to contribute to the geoPFA project.

## Development Environment

We recommend using pixi to manage environments and will add more information
here in the future.

The package version is defined dynamically from the git history, so you
might see during development something like `0.1.dev6+g2fa22ce`.
